==> feed_plugin-0.1.29.tar.gz: lib/widgets/story/story.dart <==
// import 'dart:io';

import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/widgets/videoB.dart';
// import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
// import 'package:flutter_screenutil/flutter_screenutil.dart';
// import 'package:flutter_stories/flutter_stories.dart';
// import 'package:intl/intl.dart';
import 'package:story/story.dart';
import 'package:feed_plugin/widgets/default_profile_img.dart';
import 'package:feed_plugin/utilities/colors.dart';

class StoryPage extends StatefulWidget {
  const StoryPage({
    Key key,
    @required this.images,
    @required this.user,
    @required this.text,
  });

  final List<String> images;
  final UserModel user;
  final List<String> text;
  @override
  _StoryPageState createState() => _StoryPageState();
}

class _StoryPageState extends State<StoryPage> {
  //  _momentCount = widget.images.length;

  // final _momentDuration = const Duration(seconds: 5);

  containerText(story, text) {
    return Container(
      height: ScreenUtil().screenHeight,
      width: ScreenUtil().screenWidth,
      color: storyColor[story],
      child: Align(
        alignment: Alignment.center,
        child: Text(
          text,
          textAlign: TextAlign.center,
          style: TextStyle(
              color: Colors.white, fontSize: ScreenUtil().setHeight(30)),
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Directionality(
      textDirection: TextDirection.ltr,
      child: Scaffold(
        body: StoryPageView(
          indicatorDuration: Duration(seconds: 5),
          itemBuilder: (context, pageIndex, storyIndex) {
            final story = widget.images[storyIndex];
            final text = widget.text[storyIndex];
            return Stack(
              children: [
                Positioned.fill(
                  child: Container(color: Colors.black),
                ),
                Positioned.fill(
                    child: story != null && story.length >= 4
                        ? story.substring(story.length - 3).toLowerCase() ==
                                "mp4"
                            ? VideoB(url: story, play: true)
                            : story
                                            .substring(story.length - 3)
                                            .toLowerCase() ==
                                        "png" ||
                                    story
                                            .substring(story.length - 3)
                                            .toLowerCase() ==
                                        "jpg" ||
                                    story
                                            .substring(story.length - 4)
                                            .toLowerCase() ==
                                        "jpeg"
                                ? Image.network(
                                    story,
                                    fit: BoxFit.cover,
                                  )
                                : containerText(story, text)
                        : Container()),
                Container(
                  color: Colors.black,
                  padding: const EdgeInsets.only(top: 44, left: 8, bottom: 10),
                  child: Row(
                    children: [
                      widget.user.profileImg != null &&
                              widget.user.profileImg != "" &&
                              widget.user.profileImg != "null"
                          ? Container(
                              height: 32,
                              width: 32,
                              decoration: BoxDecoration(
                                image: DecorationImage(
                                  image: NetworkImage(widget.user.profileImg),
                                  // NetworkImage(
                                  //     'https://res.cloudinary.com/feed-phonedo/image/upload/v1623062238/spy4kqhvs3liewbtnfpo.jpg'),
                                  fit: BoxFit.cover,
                                ),
                                shape: BoxShape.circle,
                              ),
                            )
                          : DefaultProfileImg(
                              firstName: widget.user.firstName,
                              lastName: widget.user.lastName,
                            ),
                      const SizedBox(
                        width: 8,
                      ),
                      Text(
                        widget.user.firstName.toString() +
                            " " +
                            widget.user.lastName.toString(),
                        style: TextStyle(
                          fontSize: 17,
                          color: Colors.white,
                          fontWeight: FontWeight.bold,
                        ),
                      ),
                    ],
                  ),
                ),
                story.substring(story.length - 3).toLowerCase() == "png" ||
                        story.substring(story.length - 3).toLowerCase() ==
                            "jpg" ||
                        story.substring(story.length - 4).toLowerCase() ==
                            "jpeg" ||
                        story.substring(story.length - 3).toLowerCase() == "mp4"
                    ? Align(
                        alignment: Alignment(0, 1),
                        child: Container(
                          width: ScreenUtil().screenWidth,
                          height: ScreenUtil().setHeight(80),
                          decoration: BoxDecoration(
                            color: Colors.white60,
                            boxShadow: [
                              BoxShadow(
                                color: Colors.grey.withOpacity(0.3),
                                spreadRadius: 5,
                                blurRadius: 7,
                              ),
                            ],
                          ),
                          child: Text(
                            text,
                            textAlign: TextAlign.center,
                            style: TextStyle(fontSize: 15),
                          ),
                        ),
                      )
                    : Container()
              ],
            );
          },
          gestureItemBuilder: (context, pageIndex, storyIndex) {
            return Align(
              alignment: Alignment.topRight,
              child: Padding(
                padding: const EdgeInsets.only(top: 32),
                child: IconButton(
                  padding: EdgeInsets.zero,
                  color: Colors.white,
                  icon: Icon(Icons.close),
                  onPressed: () {
                    Navigator.pop(context);
                  },
                ),
              ),
            );
          },
          pageLength: 1,
          storyLength: (int pageIndex) {
            return widget.images.length;
          },
          onPageLimitReached: () {
            Navigator.pop(context);
          },
        ),
      ),
    );
  }
}

==> feed_plugin-0.1.32.tar.gz: lib/widgets/story/story.dart <==
// import 'dart:io';

import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/widgets/videoB.dart';
// import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
// import 'package:flutter_screenutil/flutter_screenutil.dart';
// import 'package:flutter_stories/flutter_stories.dart';
// import 'package:intl/intl.dart';
import 'package:story/story.dart';
import 'package:feed_plugin/widgets/default_profile_img.dart';
import 'package:feed_plugin/utilities/colors.dart';

class StoryPage extends StatefulWidget {
  const StoryPage({
    Key key,
    @required this.images,
    @required this.user,
    @required this.text,
  });

  final List<String> images;
  final UserModel user;
  final List<String> text;
  @override
  _StoryPageState createState() => _StoryPageState();
}

class _StoryPageState extends State<StoryPage> {
  //  _momentCount = widget.images.length;

  // final _momentDuration = const Duration(seconds: 5);

  containerText(story, text) {
    return Container(
      height: ScreenUtil().screenHeight,
      width: ScreenUtil().screenWidth,
      color: storyColor[story],
      child: Align(
        alignment: Alignment.center,
        child: Text(
          text,
          textAlign: TextAlign.center,
          style: TextStyle(
              color: Colors.white, fontSize: ScreenUtil().setHeight(30)),
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Directionality(
      textDirection: TextDirection.ltr,
      child: Scaffold(
        body: StoryPageView(
          indicatorDuration: Duration(seconds: 5),
          itemBuilder: (context, pageIndex, storyIndex) {
            final story = widget.images[storyIndex];
            final text = widget.text[storyIndex];
            return Stack(
              children: [
                Positioned.fill(
                  child: Container(color: Colors.black),
                ),
                Positioned.fill(
                    child: story != null && story.length >= 3
                        ? story.substring(story.length - 3).toLowerCase() ==
                                "mp4"
                            ? VideoB(url: story, play: true)
                            : story
                                            .substring(story.length - 3)
                                            .toLowerCase() ==
                                        "png" ||
                                    story
                                            .substring(story.length - 3)
                                            .toLowerCase() ==
                                        "jpg" || ( story.length >= 4 &&
                                    story
                                            .substring(story.length - 4)
                                            .toLowerCase() ==
                                        "jpeg")
                                ? Image.network(
                                    story,
                                    fit: BoxFit.cover,
                                  )
                                : containerText(story, text)
                        : Container()),
                Container(
                  color: Colors.black,
                  padding: const EdgeInsets.only(top: 44, left: 8, bottom: 10),
                  child: Row(
                    children: [
                      widget.user.profileImg != null &&
                              widget.user.profileImg != "" &&
                              widget.user.profileImg != "null"
                          ? Container(
                              height: 32,
                              width: 32,
                              decoration: BoxDecoration(
                                image: DecorationImage(
                                  image: NetworkImage(widget.user.profileImg),
                                  // NetworkImage(
                                  //     'https://res.cloudinary.com/feed-phonedo/image/upload/v1623062238/spy4kqhvs3liewbtnfpo.jpg'),
                                  fit: BoxFit.cover,
                                ),
                                shape: BoxShape.circle,
                              ),
                            )
                          : DefaultProfileImg(
                              firstName: widget.user.firstName,
                              lastName: widget.user.lastName,
                            ),
                      const SizedBox(
                        width: 8,
                      ),
                      Text(
                        widget.user.firstName.toString() +
                            " " +
                            widget.user.lastName.toString(),
                        style: TextStyle(
                          fontSize: 17,
                          color: Colors.white,
                          fontWeight: FontWeight.bold,
                        ),
                      ),
                    ],
                  ),
                ),
                (story != null && story.length >= 3) && (
                story.substring(story.length - 3).toLowerCase() == "png" ||
                        story.substring(story.length - 3).toLowerCase() ==
                            "jpg" || (story.length >= 4 &&
                        story.substring(story.length - 4).toLowerCase() ==
                            "jpeg") ||
                        story.substring(story.length - 3).toLowerCase() == "mp4")
                    ? Align(
                        alignment: Alignment(0, 1),
                        child: Container(
                          width: ScreenUtil().screenWidth,
                          height: ScreenUtil().setHeight(80),
                          decoration: BoxDecoration(
                            color: Colors.white60,
                            boxShadow: [
                              BoxShadow(
                                color: Colors.grey.withOpacity(0.3),
                                spreadRadius: 5,
                                blurRadius: 7,
                              ),
                            ],
                          ),
                          child: Text(
                            text,
                            textAlign: TextAlign.center,
                            style: TextStyle(fontSize: 15),
                          ),
                        ),
                      )
                    : Container()
              ],
            );
          },
          gestureItemBuilder: (context, pageIndex, storyIndex) {
            return Align(
              alignment: Alignment.topRight,
              child: Padding(
                padding: const EdgeInsets.only(top: 32),
                child: IconButton(
                  padding: EdgeInsets.zero,
                  color: Colors.white,
                  icon: Icon(Icons.close),
                  onPressed: () {
                    Navigator.pop(context);
                  },
                ),
              ),
            );
          },
          pageLength: 1,
          storyLength: (int pageIndex) {
            return widget.images.length;
          },
          onPageLimitReached: () {
            Navigator.pop(context);
          },
        ),
      ),
    );
  }
}
